%global name rsyncxl
%global version 3.3.0
%global rpmrelease 1
# beta is either 0 or something like rc1
%global beta 0
%global distname rsync

# needed for EL9
%global _lto_cflags %{nil}

Summary: A program for synchronizing files over a network
Name: %{name}
Version: %{version}
%if "%{beta}" == "0"
Release: %{rpmrelease}%{?dist}
%else
Release: 0.%{beta}.%{rpmrelease}%{?dist}
%endif
License: GPL-3.0-or-later
Group: Applications/Internet
URL: https://rsync.samba.org/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
%if "%{beta}" == "0"
Source0: https://download.samba.org/pub/%{distname}/src/%{distname}-%{version}.tar.gz
Source1: https://download.samba.org/pub/%{distname}/src/%{distname}-patches-%{version}.tar.gz
%else
Source0: https://download.samba.org/pub/%{distname}/src-previews/%{distname}-%{version}%{beta}.tar.gz
Source1: https://download.samba.org/pub/%{distname}/src-previews/%{distname}-patches-%{version}%{beta}.tar.gz
%endif
Patch0: rsync-3.1.3-rsync-name.patch
# patches => 100 should/will be fixed in SCM
BuildRequires: libacl-devel, libattr-devel, xxhash-devel >= 0.8.0, gcc-c++
BuildRequires: openssl-devel, zlib-devel, %{_includedir}/popt.h
BuildRequires: lz4-devel >= 1.7.5
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
Rsync uses a reliable algorithm to bring remote and host files into
sync very quickly. Rsync is fast because it just sends the differences
in the files over the network instead of sending the complete
files. Rsync is often used as a very powerful mirroring process or
just as a more capable replacement for the rcp command. A technical
report which describes the rsync algorithm is included in this
package.

%prep
%if "%{beta}" == "0"
%setup -q -n %{distname}-%{version}
%setup -q -b 1 -n %{distname}-%{version}
%else
%setup -q -n %{distname}-%{version}%{beta}
%setup -q -b 1 -n %{distname}-%{version}%{beta}
%endif

# fix permissions
%{__chmod} -x support/*

# add --clone-dest option
patch -p1 -i patches/clone-dest.diff

%patch0 -p1 -b .rsync-name

%build
%configure \
  --disable-zstd \
  --with-rsync-path=%{name} \
%{nil}

%{__make}

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__make} install DESTDIR=%{buildroot} INSTALL="install -p"

# remove not packaged files
%{__rm} -f %{buildroot}%{_mandir}/man5/%{distname}d.conf.5
%{__rm} -f %{buildroot}%{_mandir}/man1/%{distname}-ssl.1
%{__rm} -f %{buildroot}%{_bindir}/%{distname}-ssl

# rename payload files
%{__mv} -vf %{buildroot}%{_bindir}/%{distname} \
  %{buildroot}%{_bindir}/%{name}
%{__mv} -vf %{buildroot}%{_mandir}/man1/%{distname}.1 \
  %{buildroot}%{_mandir}/man1/%{name}.1
%{__mv} -vf %{distname}.1.html %{name}.1.html

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc COPYING NEWS.md README.md SECURITY.md TODO tech_report.tex
%doc %{name}.1.html support/
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%changelog
* Mon Apr 08 2024 Simon Matter <simon.matter@invoca.ch> 3.3.0-1
- upgrade to 3.3.0

* Mon Dec 11 2023 Simon Matter <simon.matter@invoca.ch> 3.3.0-0.pre1.4
- build with clone-dest patch

* Tue Nov 07 2023 Simon Matter <simon.matter@invoca.ch> 3.3.0-0.pre1.3
- add patch 1f83963f59960150e8c46112daa8411324c1f209 from PR #513

* Wed Jun 28 2023 Simon Matter <simon.matter@invoca.ch> 3.3.0-0.pre1.2
- add two patches from upstream

* Mon May 01 2023 Simon Matter <simon.matter@invoca.ch> 3.3.0-0.pre1.1
- upgrade to 3.3.0pre1

* Fri Oct 21 2022 Simon Matter <simon.matter@invoca.ch> 3.2.7-1
- upgrade to 3.2.7

* Sat Sep 10 2022 Simon Matter <simon.matter@invoca.ch> 3.2.6-1
- upgrade to 3.2.6

* Mon Aug 15 2022 Simon Matter <simon.matter@invoca.ch> 3.2.5-1
- upgrade to 3.2.5

* Tue Aug 09 2022 Simon Matter <simon.matter@invoca.ch> 3.2.5-0.pre2.1
- upgrade to 3.2.5pre2

* Tue Aug 02 2022 Simon Matter <simon.matter@invoca.ch> 3.2.5-0.pre1.1
- upgrade to 3.2.5pre1

* Mon Apr 25 2022 Simon Matter <simon.matter@invoca.ch> 3.2.4-1
- upgrade to 3.2.4

* Tue Mar 29 2022 Simon Matter <simon.matter@invoca.ch> 3.2.4-0.pre4.1
- upgrade to 3.2.4pre4

* Thu Jan 20 2022 Simon Matter <simon.matter@invoca.ch> 3.2.4-0.pre3.1
- upgrade to 3.2.4pre3

* Mon Jan 17 2022 Simon Matter <simon.matter@invoca.ch> 3.2.4-0.pre2.1
- upgrade to 3.2.4pre2

* Wed Jan 05 2022 Simon Matter <simon.matter@invoca.ch> 3.2.4-0.pre1.2
- add support for EL9

* Mon Jan 03 2022 Simon Matter <simon.matter@invoca.ch> 3.2.4-0.pre1.1
- upgrade to 3.2.4pre1

* Thu Jul 15 2021 Simon Matter <simon.matter@invoca.ch> 3.2.3-5
- add patch dbb1c2d10c127b9a5f99e3e4ee5981f5222fc7e7 fixing issue #114

* Tue May 11 2021 Simon Matter <simon.matter@invoca.ch> 3.2.3-4
- add patch 6b59a35eb51b97f8fc90cfa54c1170c2ffb02b6c fixing issue #179

* Sat May 01 2021 Simon Matter <simon.matter@invoca.ch> 3.2.3-3
- add patch a6bdf313f239cabfef445bc3658b79aec8a40c37 fixing issue #176

* Tue Sep 22 2020 Simon Matter <simon.matter@invoca.ch> 3.2.3-2
- add patch 7aa2f36317be8f25f863c01e253ae64e161b1083 from PR #102

* Fri Aug 07 2020 Simon Matter <simon.matter@invoca.ch> 3.2.3-1
- upgrade to 3.2.3

* Tue Aug 04 2020 Simon Matter <simon.matter@invoca.ch> 3.2.3-0.pre1.2
- add patch 9375a8c4c2b79a9d44ceae00de7284b77d79033c fixing issue #81

* Tue Jul 28 2020 Simon Matter <simon.matter@invoca.ch> 3.2.3-0.pre1.1
- upgrade to 3.2.3pre1

* Wed Jul 08 2020 Simon Matter <simon.matter@invoca.ch> 3.2.2-2
- add important patches from SCM

* Mon Jul 06 2020 Simon Matter <simon.matter@invoca.ch> 3.2.2-1
- upgrade to 3.2.2

* Thu Jul 02 2020 Simon Matter <simon.matter@invoca.ch> 3.2.2-0.pre3.2
- disable lz4 support only on EL4

* Wed Jul 01 2020 Simon Matter <simon.matter@invoca.ch> 3.2.2-0.pre3.1
- upgrade to 3.2.2pre3

* Tue Jun 30 2020 Simon Matter <simon.matter@invoca.ch> 3.2.2-0.pre2.1
- upgrade to 3.2.2pre2

* Tue Jun 23 2020 Simon Matter <simon.matter@invoca.ch> 3.2.1-1
- upgrade to 3.2.1

* Sat Jun 20 2020 Simon Matter <simon.matter@invoca.ch> 3.2.0-1
- upgrade to 3.2.0

* Mon Apr 13 2020 Simon Matter <simon.matter@invoca.ch> 3.1.3-4
- update skip-compress patch

* Wed Apr 08 2020 Simon Matter <simon.matter@invoca.ch> 3.1.3-3
- replace dont_compress_hack with 2598ca668b739c50f4206c06dc1c8d3a561b0866
- add support for EL8

* Thu Mar 26 2020 Simon Matter <simon.matter@invoca.ch> 3.1.3-2
- add dont_compress_hack patch

* Wed Mar 11 2020 Simon Matter <simon.matter@invoca.ch> 3.1.3-1
- initial build
